summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/tags.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/tags.h')
-rw-r--r--crawl-ref/source/tags.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/tags.h b/crawl-ref/source/tags.h
index 7cf59c42c9..e2559d33fd 100644
--- a/crawl-ref/source/tags.h
+++ b/crawl-ref/source/tags.h
@@ -49,7 +49,8 @@ enum tag_minor_version
TAG_MINOR_RESET = 0, // Minor tags were reset
TAG_MINOR_SEEN_WEAPONS_ARMOUR = 1,
TAG_MINOR_BEHELD16 = 2, // Use correct type sizes for beholders
- TAG_MINOR_VERSION = 2 // Current version. (Keep equal to max.)
+ TAG_MINOR_EXCLUSION_DESC = 3, // Mark exclusion reason in annotation.
+ TAG_MINOR_VERSION = 3 // Current version. (Keep equal to max.)
};
struct enum_info